@@ -58,6 +58,11 @@
         <source>%p% - %1 of %2 at %3/s - %4 left</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../downloadwidget.cpp" line="128"/>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../downloadwidget.cpp" line="133"/>
         <source>unknown size - %1 at %2/s</source>
@@ -107,17 +112,17 @@
     </message>
     <message>
         <source>search</source>
-        <translation type="vanished">procurar</translation>
+        <translation type="vanished">Pesquisar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="253"/>
+        <location filename="../mainwindow.cpp" line="259"/>
         <source>Select file to open</source>
         <translation>Selecione o arquivo para abrir</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="254"/>
+        <location filename="../mainwindow.cpp" line="260"/>
         <source>Hypertext Files (*.htm *.html);;All Files (*.*)</source>
-        <translation>Arquivos de Hipertexto (*.htm *.html);;Todos os Arquivos (*.*)</translation>
+        <translation>Arquivos de Hipertexto (*.htm, *.html);;Todos os Arquivos (*.*)</translation>
     </message>
     <message>
         <source>Open</source>
@@ -125,191 +130,191 @@
     </message>
     <message>
         <source>Enter site or file URL:</source>
-        <translation type="vanished">Insira o sítio/site ou URL do arquivo:</translation>
+        <translation type="vanished">Insira o endereço da página eletrônica ou o arquivo:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="92"/>
+        <location filename="../mainwindow.cpp" line="98"/>
         <source>Full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="108"/>
+        <location filename="../mainwindow.cpp" line="114"/>
         <source>Move up</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="118"/>
+        <location filename="../mainwindow.cpp" line="124"/>
         <source>Move down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="127"/>
+        <location filename="../mainwindow.cpp" line="133"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="130"/>
+        <location filename="../mainwindow.cpp" line="136"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="132"/>
+        <location filename="../mainwindow.cpp" line="138"/>
         <source>Rename bookmark:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
-        <location filename="../mainwindow.cpp" line="153"/>
+        <location filename="../mainwindow.cpp" line="144"/>
+        <location filename="../mainwindow.cpp" line="159"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="177"/>
         <source>&amp;Clear history</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="190"/>
+        <location filename="../mainwindow.cpp" line="196"/>
         <source>Home</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="191"/>
+        <location filename="../mainwindow.cpp" line="197"/>
         <source>Zoom In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="193"/>
+        <location filename="../mainwindow.cpp" line="199"/>
         <source>Zoom out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="208"/>
+        <location filename="../mainwindow.cpp" line="214"/>
         <source>search in page</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="220"/>
+        <location filename="../mainwindow.cpp" line="226"/>
         <source>Add bookmark</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="228"/>
+        <location filename="../mainwindow.cpp" line="234"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="367"/>
+        <location filename="../mainwindow.cpp" line="373"/>
         <source>Keyboard Shortcuts</source>
         <translation>Atalhos de Teclado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="368"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Ctrl-F, or F3</source>
-        <translation>Ctrl+F, ou F3</translation>
+        <translation>Ctrl+F ou F3</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="368"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Find</source>
-        <translation>Procurar</translation>
+        <translation>Localizar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="368"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Shift-F3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="369"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Ctrl-R, or F5</source>
-        <translation>Ctrl+R, ou F5</translation>
+        <translation>Ctrl+R ou F5</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="369"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Reload</source>
         <translation>Recarregar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="369"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Find previous</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="370"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Ctrl-O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="370"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Esc</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="371"/>
+        <location filename="../mainwindow.cpp" line="377"/>
         <source>Stop loading/clear Find field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="371"/>
+        <location filename="../mainwindow.cpp" line="377"/>
         <source>Alt→, Alt←</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="430"/>
+        <location filename="../mainwindow.cpp" line="436"/>
         <source>Press [F11] to exit full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="514"/>
+        <location filename="../mainwindow.cpp" line="520"/>
         <source>&amp;New tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="517"/>
+        <location filename="../mainwindow.cpp" line="523"/>
         <source>&amp;Full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="519"/>
+        <location filename="../mainwindow.cpp" line="525"/>
         <source>H&amp;istory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="521"/>
+        <location filename="../mainwindow.cpp" line="527"/>
         <source>&amp;Downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="523"/>
+        <location filename="../mainwindow.cpp" line="529"/>
         <source>&amp;Bookmarks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="526"/>
+        <location filename="../mainwindow.cpp" line="532"/>
         <source>Bookmark current address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="530"/>
+        <location filename="../mainwindow.cpp" line="536"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="531"/>
+        <location filename="../mainwindow.cpp" line="537"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="533"/>
+        <location filename="../mainwindow.cpp" line="539"/>
         <source>&amp;Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="562"/>
+        <location filename="../mainwindow.cpp" line="568"/>
         <source>About MX Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="563"/>
+        <location filename="../mainwindow.cpp" line="569"/>
         <source>This is a VERY basic browser based on Qt WebEngine.
 
 The main purpose is to provide a basic document viewer for MX documentation. It could be used for LIMITED internet browsing, but it&apos;s not recommended to be used for anything important or secure because it&apos;s not a fully featured browser and its security/privacy features were not tested.
@@ -323,55 +328,55 @@ You should have received a copy of the GNU General Public License along with MX
     </message>
     <message>
         <source>Open URL</source>
-        <translation type="vanished">Abrir a URL</translation>
+        <translation type="vanished">Abrir o URL</translation>
     </message>
     <message>
         <source>Ctrl-B</source>
         <translation type="vanished">Ctrl+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="370"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Browse file to open</source>
-        <translation>Navegue pelo arquivo para abrir</translation>
+        <translation>Navegar para abrir o arquivo</translation>
     </message>
     <message>
         <source>Esc - Stop loading/clear Find field</source>
-        <translation type="vanished">Esc - Parar o carregar/limpar o campo Procurar</translation>
+        <translation type="vanished">Esc - Parar de carregar/limpar o campo ‘Localizar’</translation>
     </message>
     <message>
         <source>Alt-LeftArrow, Alt-RightArrow</source>
-        <translation type="vanished">Alt+Seta para a Esquerda, Alt+Seta para a Direita</translation>
+        <translation type="vanished">Alt+Seta para a Esquerda ou Alt+Seta para a Direita</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="372"/>
+        <location filename="../mainwindow.cpp" line="378"/>
         <source>Back/Forward</source>
         <translation>Anterior/Seguinte</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="372"/>
+        <location filename="../mainwindow.cpp" line="378"/>
         <source>F1, or ?</source>
-        <translation>F1, ou ?</translation>
+        <translation>F1 ou ?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="372"/>
+        <location filename="../mainwindow.cpp" line="378"/>
         <source>Open this help dialog</source>
-        <translation>Abrir esta janela de diálogo de ajuda</translation>
+        <translation>Abrir a janela de diálogo da ajuda</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>This tool will display the URL content in a window, window title is optional.</source>
-        <translation type="vanished">Esta ferramenta exibirá o conteúdo da URL em uma janela, o título da janela é opcional.</translation>
+        <translation type="vanished">Esta ferramenta exibirá o conteúdo do endereço de URL em uma janela e o título da janela é opcional</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="96"/>
         <source>Disable JavaScript</source>
-        <translation>Desativar JavaScript</translation>
+        <translation>Desativar o JavaScript</translation>
     </message>
     <message>
         <source>Disable workaround for broken sites</source>
-        <translation type="vanished">Desativar a solução alternativa para sites corrompidos</translation>
+        <translation type="vanished">Desativar a solução alternativa para as páginas corrompidas</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="105"/>
@@ -410,7 +415,7 @@ You should have received a copy of the GNU General Public License along with MX
     <message>
         <location filename="../main.cpp" line="107"/>
         <source>URL of the page you want to load</source>
-        <translation>URL da página que você deseja carregar</translation>
+        <translation>Endereço da página eletrônica que você quer carregar</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="109"/>
@@ -426,7 +431,7 @@ You should have received a copy of the GNU General Public License along with MX
 <context>
     <name>TabWidget</name>
     <message>
-        <location filename="../tabwidget.cpp" line="72"/>
+        <location filename="../tabwidget.cpp" line="80"/>
         <source>New Tab</source>
         <translation type="unfinished"></translation>
     </message>
